#
# spec file for package python-ospd-openvas
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-ospd-openvas
Version:        22.4.5
Release:        1.13
Summary:        An OSP server implementation
License:        AGPL-3.0-or-later
URL:            https://github.com/greenbone/ospd-openvas
Source:         https://github.com/greenbone/ospd-openvas/archive/v%{version}.tar.gz#/ospd-openvas-%{version}.tar.gz
Source98:       https://github.com/greenbone/ospd-openvas/releases/download/v%{version}/ospd-openvas-%{version}.tar.gz.asc
Source99:       https://www.greenbone.net/GBCommunitySigningKey.asc#/ospd-openvas.keyring
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module defusedxml >= 0.6}
BuildRequires:  %{python_module gnupg >= 0.4.8}
BuildRequires:  %{python_module lxml >= 4.5.2}
BuildRequires:  %{python_module paho-mqtt >= 1.5.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-defusedxml >= 0.6
Requires:       python-gnupg >= 0.4.8
Requires:       python-lxml >= 4.5.2
Requires:       python-packaging
Requires:       python-paho-mqtt >= 1.5.1
Requires:       python-psutil >= 5.5.1
Requires:       python-redis >= 3.5.3
Provides:       ospd-openvas = %{version}
Provides:       python-ospd = %{version}
Obsoletes:      python-ospd < %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Deprecated >= 1.2.10}
BuildRequires:  %{python_module packaging >= 20.4}
BuildRequires:  %{python_module psutil >= 5.5.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module redis >= 3.5.3}
# /SECTION
%python_subpackages

%description
An OSP server implementation to allow GVM to remotely control OpenVAS.

%prep
%setup -q -n ospd-openvas-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/ospd-openvas
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative ospd-openvas

%postun
%python_uninstall_alternative ospd-openvas

%check
%pytest

%files %{python_files}
%license COPYING
%doc CHANGELOG.md README.md
%python_alternative %{_bindir}/ospd-openvas
%{python_sitelib}/ospd
%{python_sitelib}/ospd_openvas*

%changelog
* Tue Jan 31 2023 Dirk Müller <dmueller@suse.com>
- update to 22.4.5:
  Added
  * Make openvas-scanner option visible for the client (#784) (#791)
  * Set openvas and nmap caps at container start, with some compose
    installations docker forgets it.
  * documentation about new features bd705d3
  * documentation and examples for credentials 5b6b668
  * description of table_driven_lsc to OSPD_PARAMS ecdb67c
  * log info for VT update (#619) fc3b80c
  * possibility to handle redis tcp connections configured in openvas 29373b7
  * package_unreliable qod_type to nvti_cache 61a3a35
  * use qod_type from advisory when available 47927c7
  * possibility to disable advisories hashsum verification 614a2ec
  * gpg verification for notus (#557) d73d03d
  * documentation for notus-scanner (#537) 9508f09
  * Notus integration (#510) 2f39d2a
  * notus advisories in get_vts (#518) f78c64a
  * merge ospd into ospd-openvas 44cc135
  * smoke test for get.vts (#513) b3c0b6b
  Changed
  * version of the OSP documentation 76d5586
  * Allow openvas access raw sockets and network within container 0eefae9
  * Extend the <get_version/> cmd and add <check_feed/> cmd (#558) c810de8
  * Use poetry as build tool for pip installations #559 f3e42c2
  * Handle script timeout as script preferences instead of server preference (#509) af97d06
  Bug Fixes
  * using empty dict as scanner-params instead of returning 404 7850833
  * within python 3.9 and higher notus results are missing b42c758
  * set to cvss2 when cvss3 is either not present or NULL 2963af4
  * check for param to be present in calculate_vts_collection_hash 358456d
  * missing reload on update_vts 96bc329
  * crash when no severity got found 30a760b
  * Stop and resume scan (#604) 41b25c2
  * stacktrace on sensor when unexpectedly closing a ssh connection 487a58e
  * do not load oids in openvas when handled by notus 15f50bb
  * ospd-openvas should not crash on missing plugin_feed_info.inc 989a876
  * mqtt network loop (#587) 9b5cecc
  * Hash calculation of NVT fields 552b5f6
  * prepare notus parser to use family when defined deb850c
  * set sentry-sdk dependency to optional 80ed7ca
  * warning on ERRMSG (#570) bf26ad0
  * missing category of notus advisories (#569) 02cfd3b
  * mqtt on_disconnect method (#538) 915f02e
  * fix dead host count (#511) (#516) 2a17e18
  * Fix get_status (#471) 866ea24
* Mon Aug 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix download archives
* Mon Aug 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove unused file
* Tue Aug 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 20.8.0
  Added
  * Add solution method to solution of vt object.
  * Add typing to daemon.py, nvticache.py and db.py.
  * Add support for alive test settings.
  * Add missing scan preferences expand_vhosts and
    test_empty_vhost.
  * Set reverse lookup options.
  * Check if the amount of vts in redis is coherent.
  * Add support for test_alive_hosts_only feature of openvas.
  * Use lock file during feed update to avoid corrupted cache.
  * Add details parameter to get_vt_iterator().
  * Add pontos as dev dependency for managing the version
    information in ospd-openvas.
  * Pass store directory to OSPDaemon init.
  * Add URI field to results for file path or webservice URL.
  * Add element to OSPD_PARAMS entries to indicate visibility
    for client.
  Changed
  * Less strict checks for the nvti cache version
  * Set self.vts to None if there is a pending feed.
  * Use the new method clear() from Vts class.
  * Start server before initialize the vts.
  * Get vts metadata from redis and reduce stored data in cache.
  * Update license to AGPL-3.0+
  * Replaced pipenv with poetry for dependency management.
    poetry install works a bit different then pipenv install.
    It installs dev packages by default and also ospd in
    editable mode. This means after running poetry install ospd will
    directly be importable in the virtual python environment.
  * Don't send host details and log messages to the client when
    Boreas is enabled.
  * Progress bar calculation do not takes in account dead hosts
  * Host progress is stored as integer.
  * Use flock for the feed lock file.
  * Improvements for fetching results from redis.
  * Add RW permission to the group on the feed lock file.
  Fixed
  * Check vt_aux for None before trying to access it.
  * Fix snmp credentials.
  * Escape script name before adding the result in an xml entity.
  * Fix handling of denied hosts.
  * Fix handling of special chars in credentials.
  * Fix type and default value of optimize_test preference.
  Removed
  * Remove use_mac_addr, vhost_ip and vhost scan preferences.
  * Handling of finished host for resume task.
  * Don't release vts explicitly.
  * Drop handling of network_scan.
* Tue Aug 11 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.0.1
